@@ -32,8 +32,6 @@
 #include <ZeroTierOne.h>
 #include "Mutex.hpp"
 
-#include "PortMapper.hpp"
-
 #include <map>
 #include <string>
 #include <assert.h>
@@ -60,7 +58,6 @@ namespace {
             , configListener(NULL)
             , pathChecker(NULL)
             , callbacks(NULL)
-            , portMapper(NULL)
         {
             callbacks = (ZT_Node_Callbacks*)malloc(sizeof(ZT_Node_Callbacks));
             memset(callbacks, 0, sizeof(ZT_Node_Callbacks));
@@ -81,9 +78,6 @@ namespace {
 
             free(callbacks);
             callbacks = NULL;
-
-            delete portMapper;
-            portMapper = NULL;
         }
 
         int64_t id;
@@ -101,8 +95,6 @@ namespace {
         jobject pathChecker;
 
         ZT_Node_Callbacks *callbacks;
-
-        ZeroTier::PortMapper *portMapper;
     };
 
 
@@ -115,7 +107,7 @@ namespace {
         enum ZT_VirtualNetworkConfigOperation operation,
         const ZT_VirtualNetworkConfig *config)
     {
-        LOGV("VritualNetworkConfigFunctionCallback");
+        LOGV("VirtualNetworkConfigFunctionCallback");
         JniRef *ref = (JniRef*)userData;
         JNIEnv *env = NULL;
         ref->jvm->GetEnv((void**)&env, JNI_VERSION_1_6);
@@ -581,7 +573,26 @@ namespace {
             return true;
         }
 
-        struct sockaddr_storage nullAddress = {0};
+        //
+        // was:
+        // struct sockaddr_storage nullAddress = {0};
+        //
+        // but was getting this warning:
+        // warning: suggest braces around initialization of subobject
+        //
+        // when building ZeroTierOne
+        //
+        struct sockaddr_storage nullAddress;
+
+        //
+        // It is possible to assume knowledge about internals of sockaddr_storage and construct
+        // correct 0-initializer, but it is simpler to just treat sockaddr_storage as opaque and
+        // use memset here to fill with 0
+        //
+        // This is also done in InetAddress.hpp for InetAddress
+        //
+        memset(&nullAddress, 0, sizeof(sockaddr_storage));
+
         jobject remoteAddressObj = NULL;
 
         if(memcmp(remoteAddress, &nullAddress, sizeof(sockaddr_storage)) != 0)
@@ -880,13 +891,6 @@ JNIEXPORT jobject JNICALL Java_com_zerotier_sdk_Node_node_1init(
         return resultObject;
     }
 
-    uint64_t nodeId = ZT_Node_address(node);
-    if (nodeId != 0) {
-        char uniqueName[64];
-        snprintf(uniqueName, sizeof(uniqueName), "ZeroTier Android/%.10llx@%u", (unsigned long long)nodeId, 9993);
-        ref->portMapper = new ZeroTier::PortMapper(9993, uniqueName);
-    }
-
     ZeroTier::Mutex::Lock lock(nodeMapMutex);
     ref->node = node;
     nodeMap.insert(std::make_pair(ref->id, ref));
@@ -1040,7 +1044,7 @@ JNIEXPORT jobject JNICALL Java_com_zerotier_sdk_Node_processWirePacket(
         inetAddressClass, "getAddress", "()[B");
     if(getAddressMethod == NULL)
     {
-        // cant find InetAddress.getAddres()
+        // cant find InetAddress.getAddress()
         return createResultObject(env, ZT_RESULT_FATAL_ERROR_INTERNAL);
     }
 
